@@ -6,6 +6,11 @@
 
 #define LJ_MAX_BUFFER 1024
 
+#ifdef		HAVE_ICONV
+#include <iconv.h>
+iconv_t		utfenc;
+#endif		/* HAVE_ICONV */
+
 void *lj_calloc(size_t nmemb, size_t size);
 void *lj_malloc(size_t size);
 void *lj_realloc(void *ptr, size_t size);
@@ -24,7 +29,7 @@ int joinstring(char *string);
 void lj_uniquename(char **name);
 void lj_error(const char *msg);
 void lj_debug(int level, const char *msg, ...);
-void setauth(const lj_server *serverinfo, lj_user *user);
+int lj_setauth(const lj_server * const serverinfo, lj_user *user);
 int md5_hex(const char *value, char **result);
 
 #endif /* UTIL_H */
