@@ -106,12 +106,10 @@ lj_get_post_response(FILE * conn, lj_event_response * response)
 }
 
 int
-lj_postevent(const lj_server * const serverinfo, const lj_user * const user,
+lj_postevent(const lj_server * const serverinfo, lj_user * user,
 	     lj_event * post, lj_event_response * response)
 {
-	char           *username,
-	               *password,
-	               *event,
+	char           *event,
 	               *subject,
 	               *usejournal,
 	               *post_text,
@@ -407,6 +405,7 @@ create_post(char *auth,
 #define STR(x)	(x ? x : "")
 	asprintf(&ret,
 		"mode=%s&%s"
+		"&ver=1"
 		"&event=%s"
 		"&subject=%s"
 		"&lineendings=%s"
