@@ -25,6 +25,9 @@ static int	debug_level = 1;
 #else
 static int	debug_level = 0;
 #endif
+#ifdef		HAVE_ICONV
+iconv_t		utfenc;
+#endif		/* HAVE_ICONV */
 
 static char	hex2char(const char *hex);
 static int	newalloc(void);
@@ -172,8 +175,10 @@ int
 lj_urlencode(const char *inbound, char **outbound)
 {
 	char            *buffer;
+	const char	*utf8;
 	int             i, j, l;
 
+	utf8 = inbound;
 #ifdef		HAVE_ICONV
 	{
 		char	*outbuf, *p;
@@ -191,27 +196,27 @@ lj_urlencode(const char *inbound, char **outbound)
 			free(p);
 			return 1;
 		}
-		*outbound = p;
-		return 0;
+		utf8 = p;
 	}
 #endif		/* HAVE_ICONV */
 
-	buffer = lj_malloc(strlen(inbound) * 3 + 1);
-	for (i = j = 0, l = strlen(inbound); i < l; i++)
+	buffer = lj_malloc(strlen(utf8) * 3 + 1);
+	for (i = j = 0, l = strlen(utf8); i < l; i++)
 	{
-		if (((inbound[i] >= 'a') && (inbound[i] <= 'z'))
-		    || ((inbound[i] >= 'A') && (inbound[i] <= 'Z'))
-		    || ((inbound[i] >= '0') && (inbound[i] <= '9')))
+		if (((utf8[i] >= 'a') && (utf8[i] <= 'z'))
+		    || ((utf8[i] >= 'A') && (utf8[i] <= 'Z'))
+		    || ((utf8[i] >= '0') && (utf8[i] <= '9'))
+		    || (utf8[i] < 0))
 		{
-			buffer[j] = inbound[i];
+			buffer[j] = utf8[i];
 			j++;
-		} else if (inbound[i] == ' ')
+		} else if (utf8[i] == ' ')
 		{
 			buffer[j] = '+';
 			j++;
 		} else
 		{
-			sprintf(&buffer[j], "%%%02X", inbound[i]);
+			sprintf(&buffer[j], "%%%02X", utf8[i]);
 			j += 3;
 		}
 	}
